##############################
VHash: Vectorizing Hash Tables
##############################

If you have documents with class labels, and you want to create numeric
representations of those documents that maximize inter-class differences, then
this package is for you. This package provides vectorizing hash tables that
quickly transform your text, optimizing for the maximum distance between
document-class vectors.

This project has a C++ backend with a python interface, allowing for maximum
speed and maximum interopability.

To get started, check out the `docs <https://lakes-legendaries.github.io/vhash/>`_!

If you will be contributing to this repo, checkout the
`developer guide <https://lakes-legendaries.github.io/vhash/dev.html>`_.
